@@ -5,7 +5,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = '0.04';
+our $VERSION = '0.03';
 
 use List::Util qw{ sum min max };
 use List::MoreUtils qw{ uniq };
@@ -13,8 +13,6 @@ use List::MoreUtils qw{ uniq };
 # FIXME: remove and use simple bbox clip?
 use Math::Geometry::Planar::GPC::Polygon qw{ new_gpc };
 
-# use Data::Dump 'dd';
-
 
 my $MAX_LEAF_POINTS = 16;       # minimum 6
 
@@ -25,64 +23,23 @@ sub new {
 
     ##  load and close polys, calc bbox
     while ( my $chain_ref = shift ) {
+        croak "Polygon should be a reference to array of points" 
+            unless ref $chain_ref;
 
-        if ( ref $chain_ref ) {
-            croak "Polygon should be a reference to array of points" 
-                unless ref $chain_ref eq 'ARRAY';
-        
-            my @epoint = ();
-            push @epoint, $chain_ref->[0]
-                unless  $chain_ref->[0]->[0] == $chain_ref->[-1]->[0]
-                    &&  $chain_ref->[0]->[1] == $chain_ref->[-1]->[1];
+        my @epoint = ();
+        push @epoint, $chain_ref->[0]
+            unless  $chain_ref->[0]->[0] == $chain_ref->[-1]->[0]
+                &&  $chain_ref->[0]->[1] == $chain_ref->[-1]->[1];
 
-            my $poly = [ @$chain_ref, @epoint ];
-            push @{$self->{poly}}, $poly;
+        my $poly = [ @$chain_ref, @epoint ];
+        push @{$self->{poly}}, $poly;
 
-            my ($xmin, $ymin, $xmax, $ymax) = polygon_bbox( @$poly );
+        my ($xmin, $ymin, $xmax, $ymax) = polygon_bbox( @$poly );
 
-            $self->{xmin} = $xmin       if  !(exists $self->{xmin})  ||  $xmin < $self->{xmin};
-            $self->{xmax} = $xmax       if  !(exists $self->{xmax})  ||  $xmax > $self->{xmax};
-            $self->{ymin} = $ymin       if  !(exists $self->{ymin})  ||  $ymin < $self->{ymin};
-            $self->{ymax} = $ymax       if  !(exists $self->{ymax})  ||  $ymax > $self->{ymax};
-        }
-        else {
-
-            open my $in, '<', $chain_ref
-                or croak "Couldn't open $chain_ref: $!";
-
-            my @bound;
-            my $pid;
-
-            while ( my $line = readline $in ) {
-                if ( $line =~ /^(-?\d+)/ ) {
-                    $pid = $1;
-                }
-                elsif ( $line =~ /^\s+([0-9.Ee+-]+)\s+([0-9.Ee+-]+)/ ) {
-                    push @bound, [ $1+0, $2+0 ];
-                }
-                elsif ( $line =~ /^END/  &&  $pid < 0 ) {
-                    @bound = ();
-                }
-                elsif ( $line =~ /^END/  &&  @bound ) {
-
-                    push @bound, $bound[0] 
-                        unless  $bound[0]->[0] == $bound[-1]->[0]
-                            &&  $bound[0]->[1] == $bound[-1]->[1];
-                    push @{$self->{poly}}, [ @bound ];
-
-                    my ($xmin, $ymin, $xmax, $ymax) = polygon_bbox( @bound );
-
-                    $self->{xmin} = $xmin       if  !(exists $self->{xmin})  ||  $xmin < $self->{xmin};
-                    $self->{xmax} = $xmax       if  !(exists $self->{xmax})  ||  $xmax > $self->{xmax};
-                    $self->{ymin} = $ymin       if  !(exists $self->{ymin})  ||  $ymin < $self->{ymin};
-                    $self->{ymax} = $ymax       if  !(exists $self->{ymax})  ||  $ymax > $self->{ymax};
-
-                    @bound = ();
-                }
-            }
-
-            close $in;
-        }
+        $self->{xmin} = $xmin       if  !(exists $self->{xmin})  ||  $xmin < $self->{xmin};
+        $self->{xmax} = $xmax       if  !(exists $self->{xmax})  ||  $xmax > $self->{xmax};
+        $self->{ymin} = $ymin       if  !(exists $self->{ymin})  ||  $ymin < $self->{ymin};
+        $self->{ymax} = $ymax       if  !(exists $self->{ymax})  ||  $ymax > $self->{ymax};
     }
 
     my $nrpoints = sum map { scalar @$_ } @{$self->{poly}};
@@ -174,26 +131,6 @@ sub contains {
 }
 
 
-sub contains_points {
-    my $self  = shift;
-    my $result = undef;
-    
-    while ( my $point = shift ) {
-        next unless ref $point;
-
-        my $isin = abs $self->contains( $point );
-        if ( defined $result ) {
-            return undef  unless  $isin == $result;
-        }
-        else {
-            $result = $isin;
-        }
-    }
-
-    return $result;
-}
-
-
 sub contains_bbox_rough {
     my $self  = shift;
     croak "Box should be 4 values xmin, ymin, xmax, ymax"
@@ -332,16 +269,11 @@ This method is effective if polygon has hundreds or more segments.
 =head2 new
 
 Takes polygons (at least one) and creates a tree structure. All polygons are outer, inners in not implemented.
-Polygon is a reference to array of points
 
     my $poly1 = [ [0,0], [0,2], [2,2], ... ];   
     ...
     my $bound = Math::Polygon::Tree->new( $poly1, $poly2, ... );
 
-or a .poly file
-
-    my $bound = Math::Polygon::Tree->new( 'boundary.poly' );
-
 =head2 contains
 
 Checks if point is inside bound polygon.
@@ -349,13 +281,6 @@ Returns 1 if point is inside polygon or 0 otherwise.
 
     if ( $bound->contains( [1,1] ) )  { ...
 
-=head2 contains_points
-
-Checks if some points is inside bound polygon.
-Returns 1 if all points is inside polygon, 0 if all outside, or B<undef>.
-
-    if ( $bound->contains_points( [1,1], [2,2] ... ) )  { ...
-
 =head2 contains_bbox_rough
 
 Checks if box is inside bound polygon.
@@ -364,7 +289,6 @@ Returns 1 if box is inside polygon, 0 if box is outside polygon or B<undef> if i
     my ($xmin, $ymin, $xmax, $ymax) = ( 1, 1, 2, 2 );
     if ( $bound->contains_bbox_rough( $xmin, $ymin, $xmax, $ymax ) )  { ... }
 
-
 =head2 contains_polygon_rough
 
 Checks if polygon is inside bound polygon.
@@ -378,17 +302,6 @@ Returns polygon's bounding box.
 
     my ( $xmin, $ymin, $xmax, $ymax ) = $bound->bbox();
 
-
-=head1 FUNCTIONS
-
-=head2 polygon_bbox
-
-Function that returns polygon's bbox.
-
-=head2 polygon_contains_point
-
-Function that tests if polygon contains point.
-
 =head1 AUTHOR
 
 liosha, C<< <liosha at cpan.org> >>
